gnash-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Gnash-commit] [SCM] Gnash branch, master, updated. f1ea754400607b2e2350


From: Rob Savoye
Subject: [Gnash-commit] [SCM] Gnash branch, master, updated. f1ea754400607b2e23500a98918dde17b100c34a
Date: Thu, 02 Sep 2010 13:35:41 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnash".

The branch, master has been updated
       via  f1ea754400607b2e23500a98918dde17b100c34a (commit)
      from  d6707fe11c8700c3b314c5f8e6ace828be4c42aa (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.savannah.gnu.org/cgit//commit/?id=f1ea754400607b2e23500a98918dde17b100c34a


commit f1ea754400607b2e23500a98918dde17b100c34a
Author: Rob Savoye <address@hidden>
Date:   Thu Sep 2 07:29:44 2010 -0600

    fix typos

diff --git a/ChangeLog-0.8.5 b/ChangeLog-0.8.5
index 5425ac3..de4ebb3 100644
--- a/ChangeLog-0.8.5
+++ b/ChangeLog-0.8.5
@@ -2977,7 +2977,7 @@
 
 2008-12-14  Rob Savoye   <address@hidden>
 
-       don't toggle done for non-persistant connections.
+       don't toggle done for non-persistent connections.
 
 2008-12-14  Rob Savoye   <address@hidden>
 
@@ -3297,7 +3297,7 @@
 
 2008-11-21  Rob Savoye   <address@hidden>
 
-       handle persistant and non persistant network connections based on the 
Keep-Alive fields.
+       handle persistent and non persistent network connections based on the 
Keep-Alive fields.
 
 2008-11-21  Rob Savoye   <address@hidden>
 
diff --git a/ChangeLog-0.8.6 b/ChangeLog-0.8.6
index aef2710..98d837b 100644
--- a/ChangeLog-0.8.6
+++ b/ChangeLog-0.8.6
@@ -148,7 +148,7 @@
 
 2009-09-06  Rob Savoye  <address@hidden>
 
-       close the network in the right places. Pass the Protocol handler to the 
thread so it's persistant.
+       close the network in the right places. Pass the Protocol handler to the 
thread so it's persistent.
 
 2009-09-06  Rob Savoye  <address@hidden>
 
diff --git a/cygnal/ChangeLog b/cygnal/ChangeLog
index c7e65c7..ff6a9b8 100644
--- a/cygnal/ChangeLog
+++ b/cygnal/ChangeLog
@@ -58,7 +58,7 @@
        * cygnal.cpp: Run forever, restarting connections after the
        disconnect.
        * handler.cpp: Trap mutex errors.
-       * http.cpp: Tweak the handling of persistant connections.  Add
+       * http.cpp: Tweak the handling of persistent connections.  Add
        statistics gathering.
        
        * buffer.cpp, cque.cpp: Turn off overly verbose debug now that
diff --git a/cygnal/crc.cpp b/cygnal/crc.cpp
index 6ea9245..54b0e20 100644
--- a/cygnal/crc.cpp
+++ b/cygnal/crc.cpp
@@ -120,7 +120,7 @@ CRcInitFile::loadFiles()
 ///
 /// @param filespec The path and file name of the disk file to parse.
 ///
-/// @return True if the file was parsed sucessfully, false if not.
+/// @return True if the file was parsed successfully, false if not.
 bool
 CRcInitFile::parseFile(const std::string& filespec)
 {
diff --git a/cygnal/crc.h b/cygnal/crc.h
index 09e5784..d420a16 100644
--- a/cygnal/crc.h
+++ b/cygnal/crc.h
@@ -57,7 +57,7 @@ public:
     ///
     /// @param filespec The path and file name of the disk file to parse.
     ///
-    /// @return True if the file was parsed sucessfully, false if not.
+    /// @return True if the file was parsed successfully, false if not.
     bool parseFile(const std::string& filespec);
 
     /// Accessors
diff --git a/cygnal/cygnal.cpp b/cygnal/cygnal.cpp
index 1621f60..d3f1ce8 100644
--- a/cygnal/cygnal.cpp
+++ b/cygnal/cygnal.cpp
@@ -1085,7 +1085,7 @@ event_handler(Network::thread_params_t *args)
                          hand->removeClient(args->netfd);
                          done = true;
                      } else {
-                         log_network("Not Done with HTTP connection for fd 
#%d, it's a persistant connection.", i);
+                         log_network("Not Done with HTTP connection for fd 
#%d, it's a persistent connection.", i);
                          
                      }
                      continue;
diff --git a/cygnal/http_server.cpp b/cygnal/http_server.cpp
index 64bda7b..026490f 100644
--- a/cygnal/http_server.cpp
+++ b/cygnal/http_server.cpp
@@ -967,7 +967,7 @@ HTTPServer::processHeaderFields(cygnal::Buffer &buf)
                    }
                    // log_debug("Requesting file: \"%s\"", _filespec);
 
-                   // HTTP 1.1 enables persistant network connections
+                   // HTTP 1.1 enables persistent network connections
                    // by default.
                    if (_version.minor > 0) {
                        log_debug("Enabling Keep Alive by default for HTTP > 
1.0");
diff --git a/cygnal/libnet/diskstream.cpp b/cygnal/libnet/diskstream.cpp
index ffb5c66..9a6d860 100644
--- a/cygnal/libnet/diskstream.cpp
+++ b/cygnal/libnet/diskstream.cpp
@@ -591,7 +591,7 @@ DiskStream::writeToDisk(const std::string &filespec, 
boost::uint8_t *data, size_
 /// @param filespec The full path and file name for the data to be
 ///    read.
 ///
-/// @return True if the file was opened sucessfully, false if not.
+/// @return True if the file was opened successfully, false if not.
 bool
 DiskStream::open(const string &filespec)
 {
@@ -607,7 +607,7 @@ DiskStream::open(const string &filespec)
 ///
 /// @param netfd An optional file descriptor to read data from
 ///
-/// @return True if the file was opened sucessfully, false if not.
+/// @return True if the file was opened successfully, false if not.
 bool
 DiskStream::open(const string &filespec, int /*netfd*/)
 {
@@ -628,7 +628,7 @@ DiskStream::open(const string &filespec, int /*netfd*/)
 /// @param statistics The optional data structure to use for
 ///    collecting statistics on this stream.
 ///
-/// @return True if the file was opened sucessfully, false if not.
+/// @return True if the file was opened successfully, false if not.
 bool
 DiskStream::open(const string &filespec, int netfd, Statistics &statistics)
 {
@@ -679,7 +679,7 @@ DiskStream::open(const string &filespec, int netfd, 
Statistics &statistics)
 
 /// \brief Stream the file that has been loaded,
 ///
-/// @return True if the data was streamed sucessfully, false if not.
+/// @return True if the data was streamed successfully, false if not.
 bool
 DiskStream::play()
 {
@@ -702,7 +702,7 @@ DiskStream::play(bool flag)
 ///
 /// @param flag True to only send the first packet, False plays entire file.
 ///
-/// @return True if the data was streamed sucessfully, false if not.
+/// @return True if the data was streamed successfully, false if not.
 bool
 DiskStream::play(int netfd, bool flag)
 {
@@ -831,7 +831,7 @@ DiskStream::play(int netfd, bool flag)
 ///
 /// @param quantity The number of frames to stream..
 ///
-/// @return True if the thumbnails were streamed sucessfully, false if not.
+/// @return True if the thumbnails were streamed successfully, false if not.
 bool
 DiskStream::preview(const string & /*filespec*/, int /*frames*/)
 {
@@ -852,7 +852,7 @@ DiskStream::preview(const string & /*filespec*/, int 
/*frames*/)
 ///
 /// @param quantity The number of thumbnails to stream..
 ///
-/// @return True if the thumbnails were streamed sucessfully, false if not.
+/// @return True if the thumbnails were streamed successfully, false if not.
 bool
 DiskStream::thumbnail(const string & /*filespec*/, int /*quantity*/)
 {
@@ -865,7 +865,7 @@ DiskStream::thumbnail(const string & /*filespec*/, int 
/*quantity*/)
 
 /// \brief Pause the stream currently being played.
 ///
-/// @return True if the stream was paused sucessfully, false if not.
+/// @return True if the stream was paused successfully, false if not.
 bool
 DiskStream::pause()
 {
@@ -899,7 +899,7 @@ DiskStream::seek(off_t offset)
 ///
 /// @param filespec The file name for the data to be written.
 ///
-/// @return True if the file was uploaded sucessfully, false if not.
+/// @return True if the file was uploaded successfully, false if not.
 bool
 DiskStream::upload(const string & /*filespec*/)
 {
diff --git a/cygnal/libnet/diskstream.h b/cygnal/libnet/diskstream.h
index e9aa313..efc40f9 100644
--- a/cygnal/libnet/diskstream.h
+++ b/cygnal/libnet/diskstream.h
@@ -106,7 +106,7 @@ public:
     /// @param statistics The optional data structure to use for
     ///                collecting statistics on this stream.
     ///
-    /// @return True if the file was opened sucessfully, false if not.
+    /// @return True if the file was opened successfully, false if not.
     DSOEXPORT bool open(const std::string &filespec);
     DSOEXPORT bool open(const std::string &filespec, int netfd);
     DSOEXPORT bool open(const std::string &filespec, int netfd, 
gnash::Statistics  &statistics);
@@ -117,7 +117,7 @@ public:
     ///
     /// @param flag True to play the entire file, false to play part.
     ///
-    /// @return True if the data was streamed sucessfully, false if not.
+    /// @return True if the data was streamed successfully, false if not.
     bool play();
     bool play(bool flag);
     bool play(int netfd, bool flag);
@@ -132,7 +132,7 @@ public:
     ///
     /// @param quantity The number of frames to stream..
     ///
-    /// @return True if the thumbnails were streamed sucessfully, false if not.
+    /// @return True if the thumbnails were streamed successfully, false if 
not.
     bool preview(const std::string &filespec, int frames);
     
     /// \brief Stream a series of thumbnails.
@@ -145,12 +145,12 @@ public:
     ///
     /// @param quantity The number of thumbnails to stream..
     ///
-    /// @return True if the thumbnails were streamed sucessfully, false if not.
+    /// @return True if the thumbnails were streamed successfully, false if 
not.
     bool thumbnail(const std::string &filespec, int quantity);
     
     /// \brief Pause the stream currently being played.
     ///
-    /// @return True if the stream was paused sucessfully, false if not.
+    /// @return True if the stream was paused successfully, false if not.
     bool pause();
     
     /// \brief Seek within the stream.
@@ -169,7 +169,7 @@ public:
     ///
     /// @param filespec The file name for the data to be written.
     ///
-    /// @return True if the file was uploaded sucessfully, false if not.
+    /// @return True if the file was uploaded successfully, false if not.
     bool upload(const std::string &filespec);
     
     // Stream a single "real-time" source.
diff --git a/cygnal/libnet/http.cpp b/cygnal/libnet/http.cpp
index a04ab12..b835e0b 100644
--- a/cygnal/libnet/http.cpp
+++ b/cygnal/libnet/http.cpp
@@ -219,7 +219,7 @@ HTTP::processHeaderFields(cygnal::Buffer *buf)
                    }
                    log_debug("Requesting file: \"%s\"", _filespec);
 
-                   // HTTP 1.1 enables persistant network connections
+                   // HTTP 1.1 enables persistent network connections
                    // by default.
                    if (_version.minor > 0) {
                        log_debug("Enabling Keep Alive by default for HTTP > 
1.0");
diff --git a/libbase/curl_adapter.cpp b/libbase/curl_adapter.cpp
index ccb61ed..dbc3124 100644
--- a/libbase/curl_adapter.cpp
+++ b/libbase/curl_adapter.cpp
@@ -678,7 +678,7 @@ CurlStreamFile::fillCache(std::streamsize size)
         {
             if ( errno == EINTR )
             {
-                // we got interupted by a signal
+                // we got interrupted by a signal
                 // let's consider this as a timeout
 #ifdef GNASH_CURL_VERBOSE
                 log_debug("select() was interrupted by a signal");
diff --git a/libcore/parser/SWFMovieDefinition.h 
b/libcore/parser/SWFMovieDefinition.h
index d94e283..81d1f3f 100644
--- a/libcore/parser/SWFMovieDefinition.h
+++ b/libcore/parser/SWFMovieDefinition.h
@@ -529,7 +529,7 @@ private:
         _bytes_loaded=bytes;
     }
 
-    /// A flag set to true when load cancelation is requested
+    /// A flag set to true when load cancellation is requested
     bool _loadingCanceled;
 
     /// Movies we import resources from

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog-0.8.5                       |    4 ++--
 ChangeLog-0.8.6                       |    2 +-
 cygnal/ChangeLog                      |    2 +-
 cygnal/crc.cpp                        |    2 +-
 cygnal/crc.h                          |    2 +-
 cygnal/cygnal.cpp                     |    2 +-
 cygnal/http_server.cpp                |    2 +-
 cygnal/libnet/diskstream.cpp          |   18 +++++++++---------
 cygnal/libnet/diskstream.h            |   12 ++++++------
 cygnal/libnet/http.cpp                |    2 +-
 cygnal/libnet/network.cpp             |   22 +++++++++++-----------
 cygnal/libnet/rtmp_client.cpp         |    4 ++--
 libbase/curl_adapter.cpp              |    2 +-
 libcore/parser/SWFMovieDefinition.cpp |    4 ++--
 libcore/parser/SWFMovieDefinition.h   |    2 +-
 15 files changed, 41 insertions(+), 41 deletions(-)


hooks/post-receive
diff --git a/cygnal/libnet/network.cpp b/cygnal/libnet/network.cpp
index 0ca1980..d2cbd8b 100644
--- a/cygnal/libnet/network.cpp
+++ b/cygnal/libnet/network.cpp
@@ -353,9 +353,9 @@ Network::newConnection(bool block, int fd)
             return 1;
         }
        
         // If interupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
-            log_debug(_("The accept() socket for fd #%d was interupted by a 
system call"), fd);
+            log_debug(_("The accept() socket for fd #%d was interrupted by a 
system call"), fd);
         }
 
         if (ret == -1) {
@@ -440,9 +440,9 @@ Network::connectSocket(const string &sockname)
 
         ret = ::select(_sockfd+1, &fdset, NULL, NULL, &tval);
 
         // If interupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
-           log_debug(_("The connect() socket for fd %d was interupted by a 
system call"),
+           log_debug(_("The connect() socket for fd %d was interrupted by a 
system call"),
                      _sockfd);
            continue;
        }
@@ -598,7 +598,7 @@ Network::createClient(const string &hostname, short port)
 
         ret = ::select(_sockfd+1, &fdset, NULL, NULL, &tval);
 
         // If interupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
             log_debug(_("The connect() socket for fd %d was interrupted "
                         "by a system call"), _sockfd);
@@ -937,9 +937,9 @@ Network::readNet(int fd, byte_t *buffer, int nbytes, int 
timeout)
 #endif
        }
 
         // If interupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
-            log_error (_("The socket for fd #%d was interupted by a system 
call"), fd);
+            log_error (_("The socket for fd #%d was interrupted by a system 
call"), fd);
         }
 
         if (ret == -1) {
@@ -1111,9 +1111,9 @@ Network::writeNet(int fd, const byte_t *buffer, int 
nbytes, int timeout)
         ret = select(fd+1, NULL, &fdset, NULL, &tval);
 #endif
        
         // If interupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
-            log_error (_("The socket for fd #%d was interupted by a system 
call"), fd);
+            log_error (_("The socket for fd #%d was interrupted by a system 
call"), fd);
         }
 
         if (ret == -1) {
@@ -1443,9 +1443,9 @@ Network::waitForNetData(int limit, fd_set files)
     tval.tv_usec = timeout * 1000; // was 1000000
     int ret = select(limit+1, &fdset, NULL, NULL, &tval);
 #endif
     // If interupted by a system call, try again
     if (ret == -1 && errno == EINTR) {
-       log_error (_("Waiting for data was interupted by a system call"));
+       log_error (_("Waiting for data was interrupted by a system call"));
     }
     
     if (ret == -1) {
@@ -353,9 +353,9 @@ Network::newConnection(bool block, int fd)
         }
        
-        // If interupted by a system call, try again
+        // If interrupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
@@ -440,9 +440,9 @@ Network::connectSocket(const string &sockname)
         ret = ::select(_sockfd+1, &fdset, NULL, NULL, &tval);
 
-        // If interupted by a system call, try again
+        // If interrupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
@@ -598,7 +598,7 @@ Network::createClient(const string &hostname, short port)
         ret = ::select(_sockfd+1, &fdset, NULL, NULL, &tval);
 
-        // If interupted by a system call, try again
+        // If interrupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
             log_debug(_("The connect() socket for fd %d was interrupted "
@@ -937,9 +937,9 @@ Network::readNet(int fd, byte_t *buffer, int nbytes, int 
        }
 
-        // If interupted by a system call, try again
+        // If interrupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
@@ -1111,9 +1111,9 @@ Network::writeNet(int fd, const byte_t *buffer, int 
 #endif
        
-        // If interupted by a system call, try again
+        // If interrupted by a system call, try again
         if (ret == -1 && errno == EINTR) {
@@ -1443,9 +1443,9 @@ Network::waitForNetData(int limit, fd_set files)
     int ret = select(limit+1, &fdset, NULL, NULL, &tval);
 #endif
-    // If interupted by a system call, try again
+    // If interrupted by a system call, try again
     if (ret == -1 && errno == EINTR) {
diff --git a/cygnal/libnet/rtmp_client.cpp b/cygnal/libnet/rtmp_client.cpp
index 2936288..efb5d70 100644
--- a/cygnal/libnet/rtmp_client.cpp
+++ b/cygnal/libnet/rtmp_client.cpp
@@ -347,7 +347,7 @@ RTMPClient::connectToServer(const std::string &url)
            boost::shared_ptr<RTMPMsg> msg = msgque.front();
            msgque.pop_front();
            if (msg->getStatus() ==  RTMPMsg::NC_CONNECT_SUCCESS) {
-               log_network("Sent NetConnection Connect message sucessfully");
+               log_network("Sent NetConnection Connect message successfully");
            }               
            if (msg->getStatus() ==  RTMPMsg::NC_CONNECT_FAILED) {
                log_error("Couldn't send NetConnection Connect message,");
@@ -703,7 +703,7 @@ RTMPClient::clientFinish(cygnal::Buffer &data)
        _connected = false;
     }
 
     // Since the handshake completed sucessfully, we're connected.
     _connected = true;
 
     return handshake1;
@@ -703,7 +703,7 @@ RTMPClient::clientFinish(cygnal::Buffer &data)
     }
 
-    // Since the handshake completed sucessfully, we're connected.
+    // Since the handshake completed successfully, we're connected.
     _connected = true;
 
diff --git a/libcore/parser/SWFMovieDefinition.cpp 
b/libcore/parser/SWFMovieDefinition.cpp
index db8085d..d7bcdb0 100644
--- a/libcore/parser/SWFMovieDefinition.cpp
+++ b/libcore/parser/SWFMovieDefinition.cpp
@@ -166,7 +166,7 @@ SWFMovieDefinition::SWFMovieDefinition(const RunResources& 
runResources)
 
 SWFMovieDefinition::~SWFMovieDefinition()
 {
     // Request cancelation of the loading thread
     _loadingCanceled = true;
 }
 
@@ -486,7 +486,7 @@ SWFMovieDefinition::read_all_swf()
         while (left) {
 
             if (_loadingCanceled) {
-                log_debug("Loading thread cancelation requested, "
+                log_debug("Loading thread cancellation requested, "
                         "returning from read_all_swf");
                 return;
             }
@@ -166,7 +166,7 @@ SWFMovieDefinition::SWFMovieDefinition(const RunResources& 
 SWFMovieDefinition::~SWFMovieDefinition()
 {
-    // Request cancelation of the loading thread
+    // Request cancellation of the loading thread
     _loadingCanceled = true;
 }
-- 
Gnash



reply via email to

[Prev in Thread] Current Thread [Next in Thread]